@@ -203,14 +203,17 @@ class Url(Raw):
     """
     A string representation of a Url
     """
-    def __init__(self, endpoint):
+    def __init__(self, endpoint, absolute=False):
         super(Url, self).__init__()
         self.endpoint = endpoint
+        self.absolute = absolute
 
     def output(self, key, obj):
         try:
             data = to_marshallable_type(obj)
-            o = urlparse(url_for(self.endpoint, **data))
+            o = urlparse(url_for(self.endpoint, _external = self.absolute, **data))
+            if self.absolute:
+                return urlunparse((o.scheme, o.netloc, o.path, "", "", ""))
             return urlunparse(("", "", o.path, "", "", ""))
         except TypeError as te:
             raise MarshallingException(te)
